@@ -57,7 +57,9 @@ __all__ = (
     "ResourceTypeType",
     "ScopeNameType",
     "StatusType",
+    "ComputeOptimizerServiceName",
     "ServiceName",
+    "ResourceServiceName",
 )
 
 
@@ -314,6 +316,7 @@ ResourceTypeType = Literal[
 ]
 ScopeNameType = Literal["AccountId", "Organization", "ResourceArn"]
 StatusType = Literal["Active", "Failed", "Inactive", "Pending"]
+ComputeOptimizerServiceName = Literal["compute-optimizer"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -345,6 +348,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -467,6 +471,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -615,3 +620,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
