@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
+from typing_extensions import NotRequired
+
 from .literals import (
     CpuVendorArchitectureType,
     CurrencyType,
@@ -139,100 +141,82 @@ __all__ = (
 AccountEnrollmentStatusTypeDef = TypedDict(
     "AccountEnrollmentStatusTypeDef",
     {
-        "accountId": str,
-        "status": StatusType,
-        "statusReason": str,
-        "lastUpdatedTimestamp": datetime,
+        "accountId": NotRequired[str],
+        "status": NotRequired[StatusType],
+        "statusReason": NotRequired[str],
+        "lastUpdatedTimestamp": NotRequired[datetime],
     },
-    total=False,
 )
 
 AutoScalingGroupConfigurationTypeDef = TypedDict(
     "AutoScalingGroupConfigurationTypeDef",
     {
-        "desiredCapacity": int,
-        "minSize": int,
-        "maxSize": int,
-        "instanceType": str,
+        "desiredCapacity": NotRequired[int],
+        "minSize": NotRequired[int],
+        "maxSize": NotRequired[int],
+        "instanceType": NotRequired[str],
     },
-    total=False,
 )
 
 AutoScalingGroupRecommendationOptionTypeDef = TypedDict(
     "AutoScalingGroupRecommendationOptionTypeDef",
     {
-        "configuration": "AutoScalingGroupConfigurationTypeDef",
-        "projectedUtilizationMetrics": List["UtilizationMetricTypeDef"],
-        "performanceRisk": float,
-        "rank": int,
-        "savingsOpportunity": "SavingsOpportunityTypeDef",
-        "migrationEffort": MigrationEffortType,
+        "configuration": NotRequired["AutoScalingGroupConfigurationTypeDef"],
+        "projectedUtilizationMetrics": NotRequired[List["UtilizationMetricTypeDef"]],
+        "performanceRisk": NotRequired[float],
+        "rank": NotRequired[int],
+        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
+        "migrationEffort": NotRequired[MigrationEffortType],
     },
-    total=False,
 )
 
 AutoScalingGroupRecommendationTypeDef = TypedDict(
     "AutoScalingGroupRecommendationTypeDef",
     {
-        "accountId": str,
-        "autoScalingGroupArn": str,
-        "autoScalingGroupName": str,
-        "finding": FindingType,
-        "utilizationMetrics": List["UtilizationMetricTypeDef"],
-        "lookBackPeriodInDays": float,
-        "currentConfiguration": "AutoScalingGroupConfigurationTypeDef",
-        "recommendationOptions": List["AutoScalingGroupRecommendationOptionTypeDef"],
-        "lastRefreshTimestamp": datetime,
-        "currentPerformanceRisk": CurrentPerformanceRiskType,
-        "effectiveRecommendationPreferences": "EffectiveRecommendationPreferencesTypeDef",
-        "inferredWorkloadTypes": List[InferredWorkloadTypeType],
+        "accountId": NotRequired[str],
+        "autoScalingGroupArn": NotRequired[str],
+        "autoScalingGroupName": NotRequired[str],
+        "finding": NotRequired[FindingType],
+        "utilizationMetrics": NotRequired[List["UtilizationMetricTypeDef"]],
+        "lookBackPeriodInDays": NotRequired[float],
+        "currentConfiguration": NotRequired["AutoScalingGroupConfigurationTypeDef"],
+        "recommendationOptions": NotRequired[List["AutoScalingGroupRecommendationOptionTypeDef"]],
+        "lastRefreshTimestamp": NotRequired[datetime],
+        "currentPerformanceRisk": NotRequired[CurrentPerformanceRiskType],
+        "effectiveRecommendationPreferences": NotRequired[
+            "EffectiveRecommendationPreferencesTypeDef"
+        ],
+        "inferredWorkloadTypes": NotRequired[List[InferredWorkloadTypeType]],
     },
-    total=False,
 )
 
 CurrentPerformanceRiskRatingsTypeDef = TypedDict(
     "CurrentPerformanceRiskRatingsTypeDef",
     {
-        "high": int,
-        "medium": int,
-        "low": int,
-        "veryLow": int,
+        "high": NotRequired[int],
+        "medium": NotRequired[int],
+        "low": NotRequired[int],
+        "veryLow": NotRequired[int],
     },
-    total=False,
 )
 
-_RequiredDeleteRecommendationPreferencesRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteRecommendationPreferencesRequestRequestTypeDef",
+DeleteRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "DeleteRecommendationPreferencesRequestRequestTypeDef",
     {
         "resourceType": ResourceTypeType,
         "recommendationPreferenceNames": Sequence[RecommendationPreferenceNameType],
+        "scope": NotRequired["ScopeTypeDef"],
     },
 )
-_OptionalDeleteRecommendationPreferencesRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteRecommendationPreferencesRequestRequestTypeDef",
-    {
-        "scope": "ScopeTypeDef",
-    },
-    total=False,
-)
-
-
-class DeleteRecommendationPreferencesRequestRequestTypeDef(
-    _RequiredDeleteRecommendationPreferencesRequestRequestTypeDef,
-    _OptionalDeleteRecommendationPreferencesRequestRequestTypeDef,
-):
-    pass
-
 
 DescribeRecommendationExportJobsRequestRequestTypeDef = TypedDict(
     "DescribeRecommendationExportJobsRequestRequestTypeDef",
     {
-        "jobIds": Sequence[str],
-        "filters": Sequence["JobFilterTypeDef"],
-        "nextToken": str,
-        "maxResults": int,
+        "jobIds": NotRequired[Sequence[str]],
+        "filters": NotRequired[Sequence["JobFilterTypeDef"]],
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
     },
-    total=False,
 )
 
 DescribeRecommendationExportJobsResponseTypeDef = TypedDict(
@@ -247,76 +231,57 @@ DescribeRecommendationExportJobsResponseTypeDef = TypedDict(
 EBSFilterTypeDef = TypedDict(
     "EBSFilterTypeDef",
     {
-        "name": Literal["Finding"],
-        "values": Sequence[str],
+        "name": NotRequired[Literal["Finding"]],
+        "values": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 EBSUtilizationMetricTypeDef = TypedDict(
     "EBSUtilizationMetricTypeDef",
     {
-        "name": EBSMetricNameType,
-        "statistic": MetricStatisticType,
-        "value": float,
+        "name": NotRequired[EBSMetricNameType],
+        "statistic": NotRequired[MetricStatisticType],
+        "value": NotRequired[float],
     },
-    total=False,
 )
 
 EffectiveRecommendationPreferencesTypeDef = TypedDict(
     "EffectiveRecommendationPreferencesTypeDef",
     {
-        "cpuVendorArchitectures": List[CpuVendorArchitectureType],
-        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
-        "inferredWorkloadTypes": InferredWorkloadTypesPreferenceType,
+        "cpuVendorArchitectures": NotRequired[List[CpuVendorArchitectureType]],
+        "enhancedInfrastructureMetrics": NotRequired[EnhancedInfrastructureMetricsType],
+        "inferredWorkloadTypes": NotRequired[InferredWorkloadTypesPreferenceType],
     },
-    total=False,
 )
 
 EnrollmentFilterTypeDef = TypedDict(
     "EnrollmentFilterTypeDef",
     {
-        "name": Literal["Status"],
-        "values": Sequence[str],
+        "name": NotRequired[Literal["Status"]],
+        "values": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 EstimatedMonthlySavingsTypeDef = TypedDict(
     "EstimatedMonthlySavingsTypeDef",
     {
-        "currency": CurrencyType,
-        "value": float,
+        "currency": NotRequired[CurrencyType],
+        "value": NotRequired[float],
     },
-    total=False,
 )
 
-_RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
-    "_RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
+ExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
+    "ExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
+        "accountIds": NotRequired[Sequence[str]],
+        "filters": NotRequired[Sequence["FilterTypeDef"]],
+        "fieldsToExport": NotRequired[Sequence[ExportableAutoScalingGroupFieldType]],
+        "fileFormat": NotRequired[Literal["Csv"]],
+        "includeMemberAccounts": NotRequired[bool],
+        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
     },
 )
-_OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
-    "_OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
-    {
-        "accountIds": Sequence[str],
-        "filters": Sequence["FilterTypeDef"],
-        "fieldsToExport": Sequence[ExportableAutoScalingGroupFieldType],
-        "fileFormat": Literal["Csv"],
-        "includeMemberAccounts": bool,
-        "recommendationPreferences": "RecommendationPreferencesTypeDef",
-    },
-    total=False,
-)
-
-
-class ExportAutoScalingGroupRecommendationsRequestRequestTypeDef(
-    _RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef,
-    _OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef,
-):
-    pass
-
 
 ExportAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
     "ExportAutoScalingGroupRecommendationsResponseTypeDef",
@@ -330,36 +295,21 @@ ExportAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
 ExportDestinationTypeDef = TypedDict(
     "ExportDestinationTypeDef",
     {
-        "s3": "S3DestinationTypeDef",
+        "s3": NotRequired["S3DestinationTypeDef"],
     },
-    total=False,
 )
 
-_RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
-    "_RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef",
+ExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
+    "ExportEBSVolumeRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
+        "accountIds": NotRequired[Sequence[str]],
+        "filters": NotRequired[Sequence["EBSFilterTypeDef"]],
+        "fieldsToExport": NotRequired[Sequence[ExportableVolumeFieldType]],
+        "fileFormat": NotRequired[Literal["Csv"]],
+        "includeMemberAccounts": NotRequired[bool],
     },
 )
-_OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
-    "_OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef",
-    {
-        "accountIds": Sequence[str],
-        "filters": Sequence["EBSFilterTypeDef"],
-        "fieldsToExport": Sequence[ExportableVolumeFieldType],
-        "fileFormat": Literal["Csv"],
-        "includeMemberAccounts": bool,
-    },
-    total=False,
-)
-
-
-class ExportEBSVolumeRecommendationsRequestRequestTypeDef(
-    _RequiredExportEBSVolumeRecommendationsRequestRequestTypeDef,
-    _OptionalExportEBSVolumeRecommendationsRequestRequestTypeDef,
-):
-    pass
-
 
 ExportEBSVolumeRecommendationsResponseTypeDef = TypedDict(
     "ExportEBSVolumeRecommendationsResponseTypeDef",
@@ -370,32 +320,18 @@ ExportEBSVolumeRecommendationsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
-    "_RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef",
+ExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
+    "ExportEC2InstanceRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
+        "accountIds": NotRequired[Sequence[str]],
+        "filters": NotRequired[Sequence["FilterTypeDef"]],
+        "fieldsToExport": NotRequired[Sequence[ExportableInstanceFieldType]],
+        "fileFormat": NotRequired[Literal["Csv"]],
+        "includeMemberAccounts": NotRequired[bool],
+        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
     },
 )
-_OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
-    "_OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef",
-    {
-        "accountIds": Sequence[str],
-        "filters": Sequence["FilterTypeDef"],
-        "fieldsToExport": Sequence[ExportableInstanceFieldType],
-        "fileFormat": Literal["Csv"],
-        "includeMemberAccounts": bool,
-        "recommendationPreferences": "RecommendationPreferencesTypeDef",
-    },
-    total=False,
-)
-
-
-class ExportEC2InstanceRecommendationsRequestRequestTypeDef(
-    _RequiredExportEC2InstanceRecommendationsRequestRequestTypeDef,
-    _OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef,
-):
-    pass
-
 
 ExportEC2InstanceRecommendationsResponseTypeDef = TypedDict(
     "ExportEC2InstanceRecommendationsResponseTypeDef",
@@ -406,31 +342,17 @@ ExportEC2InstanceRecommendationsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
-    "_RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef",
+ExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
+    "ExportLambdaFunctionRecommendationsRequestRequestTypeDef",
     {
         "s3DestinationConfig": "S3DestinationConfigTypeDef",
+        "accountIds": NotRequired[Sequence[str]],
+        "filters": NotRequired[Sequence["LambdaFunctionRecommendationFilterTypeDef"]],
+        "fieldsToExport": NotRequired[Sequence[ExportableLambdaFunctionFieldType]],
+        "fileFormat": NotRequired[Literal["Csv"]],
+        "includeMemberAccounts": NotRequired[bool],
     },
 )
-_OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
-    "_OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef",
-    {
-        "accountIds": Sequence[str],
-        "filters": Sequence["LambdaFunctionRecommendationFilterTypeDef"],
-        "fieldsToExport": Sequence[ExportableLambdaFunctionFieldType],
-        "fileFormat": Literal["Csv"],
-        "includeMemberAccounts": bool,
-    },
-    total=False,
-)
-
-
-class ExportLambdaFunctionRecommendationsRequestRequestTypeDef(
-    _RequiredExportLambdaFunctionRecommendationsRequestRequestTypeDef,
-    _OptionalExportLambdaFunctionRecommendationsRequestRequestTypeDef,
-):
-    pass
-
 
 ExportLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
     "ExportLambdaFunctionRecommendationsResponseTypeDef",
@@ -444,23 +366,21 @@ ExportLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
-        "name": FilterNameType,
-        "values": Sequence[str],
+        "name": NotRequired[FilterNameType],
+        "values": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 GetAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
     "GetAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
-        "accountIds": Sequence[str],
-        "autoScalingGroupArns": Sequence[str],
-        "nextToken": str,
-        "maxResults": int,
-        "filters": Sequence["FilterTypeDef"],
-        "recommendationPreferences": "RecommendationPreferencesTypeDef",
+        "accountIds": NotRequired[Sequence[str]],
+        "autoScalingGroupArns": NotRequired[Sequence[str]],
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
+        "filters": NotRequired[Sequence["FilterTypeDef"]],
+        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
     },
-    total=False,
 )
 
 GetAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
@@ -476,13 +396,12 @@ GetAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
 GetEBSVolumeRecommendationsRequestRequestTypeDef = TypedDict(
     "GetEBSVolumeRecommendationsRequestRequestTypeDef",
     {
-        "volumeArns": Sequence[str],
-        "nextToken": str,
-        "maxResults": int,
-        "filters": Sequence["EBSFilterTypeDef"],
-        "accountIds": Sequence[str],
+        "volumeArns": NotRequired[Sequence[str]],
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
+        "filters": NotRequired[Sequence["EBSFilterTypeDef"]],
+        "accountIds": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 GetEBSVolumeRecommendationsResponseTypeDef = TypedDict(
@@ -498,14 +417,13 @@ GetEBSVolumeRecommendationsResponseTypeDef = TypedDict(
 GetEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
     "GetEC2InstanceRecommendationsRequestRequestTypeDef",
     {
-        "instanceArns": Sequence[str],
-        "nextToken": str,
-        "maxResults": int,
-        "filters": Sequence["FilterTypeDef"],
-        "accountIds": Sequence[str],
-        "recommendationPreferences": "RecommendationPreferencesTypeDef",
+        "instanceArns": NotRequired[Sequence[str]],
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
+        "filters": NotRequired[Sequence["FilterTypeDef"]],
+        "accountIds": NotRequired[Sequence[str]],
+        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
     },
-    total=False,
 )
 
 GetEC2InstanceRecommendationsResponseTypeDef = TypedDict(
@@ -518,31 +436,17 @@ GetEC2InstanceRecommendationsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
-    "_RequiredGetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
+GetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
+    "GetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
     {
         "instanceArn": str,
         "stat": MetricStatisticType,
         "period": int,
         "startTime": Union[datetime, str],
         "endTime": Union[datetime, str],
+        "recommendationPreferences": NotRequired["RecommendationPreferencesTypeDef"],
     },
 )
-_OptionalGetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
-    "_OptionalGetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
-    {
-        "recommendationPreferences": "RecommendationPreferencesTypeDef",
-    },
-    total=False,
-)
-
-
-class GetEC2RecommendationProjectedMetricsRequestRequestTypeDef(
-    _RequiredGetEC2RecommendationProjectedMetricsRequestRequestTypeDef,
-    _OptionalGetEC2RecommendationProjectedMetricsRequestRequestTypeDef,
-):
-    pass
-
 
 GetEC2RecommendationProjectedMetricsResponseTypeDef = TypedDict(
     "GetEC2RecommendationProjectedMetricsResponseTypeDef",
@@ -582,11 +486,10 @@ GetEnrollmentStatusResponseTypeDef = TypedDict(
 GetEnrollmentStatusesForOrganizationRequestRequestTypeDef = TypedDict(
     "GetEnrollmentStatusesForOrganizationRequestRequestTypeDef",
     {
-        "filters": Sequence["EnrollmentFilterTypeDef"],
-        "nextToken": str,
-        "maxResults": int,
+        "filters": NotRequired[Sequence["EnrollmentFilterTypeDef"]],
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
     },
-    total=False,
 )
 
 GetEnrollmentStatusesForOrganizationResponseTypeDef = TypedDict(
@@ -601,13 +504,12 @@ GetEnrollmentStatusesForOrganizationResponseTypeDef = TypedDict(
 GetLambdaFunctionRecommendationsRequestRequestTypeDef = TypedDict(
     "GetLambdaFunctionRecommendationsRequestRequestTypeDef",
     {
-        "functionArns": Sequence[str],
-        "accountIds": Sequence[str],
-        "filters": Sequence["LambdaFunctionRecommendationFilterTypeDef"],
-        "nextToken": str,
-        "maxResults": int,
+        "functionArns": NotRequired[Sequence[str]],
+        "accountIds": NotRequired[Sequence[str]],
+        "filters": NotRequired[Sequence["LambdaFunctionRecommendationFilterTypeDef"]],
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
     },
-    total=False,
 )
 
 GetLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
@@ -622,36 +524,21 @@ GetLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
 GetRecommendationErrorTypeDef = TypedDict(
     "GetRecommendationErrorTypeDef",
     {
-        "identifier": str,
-        "code": str,
-        "message": str,
+        "identifier": NotRequired[str],
+        "code": NotRequired[str],
+        "message": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredGetRecommendationPreferencesRequestRequestTypeDef = TypedDict(
-    "_RequiredGetRecommendationPreferencesRequestRequestTypeDef",
+GetRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "GetRecommendationPreferencesRequestRequestTypeDef",
     {
         "resourceType": ResourceTypeType,
+        "scope": NotRequired["ScopeTypeDef"],
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
     },
 )
-_OptionalGetRecommendationPreferencesRequestRequestTypeDef = TypedDict(
-    "_OptionalGetRecommendationPreferencesRequestRequestTypeDef",
-    {
-        "scope": "ScopeTypeDef",
-        "nextToken": str,
-        "maxResults": int,
-    },
-    total=False,
-)
-
-
-class GetRecommendationPreferencesRequestRequestTypeDef(
-    _RequiredGetRecommendationPreferencesRequestRequestTypeDef,
-    _OptionalGetRecommendationPreferencesRequestRequestTypeDef,
-):
-    pass
-
 
 GetRecommendationPreferencesResponseTypeDef = TypedDict(
     "GetRecommendationPreferencesResponseTypeDef",
@@ -665,11 +552,10 @@ GetRecommendationPreferencesResponseTypeDef = TypedDict(
 GetRecommendationSummariesRequestRequestTypeDef = TypedDict(
     "GetRecommendationSummariesRequestRequestTypeDef",
     {
-        "accountIds": Sequence[str],
-        "nextToken": str,
-        "maxResults": int,
+        "accountIds": NotRequired[Sequence[str]],
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
     },
-    total=False,
 )
 
 GetRecommendationSummariesResponseTypeDef = TypedDict(
@@ -684,211 +570,187 @@ GetRecommendationSummariesResponseTypeDef = TypedDict(
 InstanceRecommendationOptionTypeDef = TypedDict(
     "InstanceRecommendationOptionTypeDef",
     {
-        "instanceType": str,
-        "projectedUtilizationMetrics": List["UtilizationMetricTypeDef"],
-        "platformDifferences": List[PlatformDifferenceType],
-        "performanceRisk": float,
-        "rank": int,
-        "savingsOpportunity": "SavingsOpportunityTypeDef",
-        "migrationEffort": MigrationEffortType,
+        "instanceType": NotRequired[str],
+        "projectedUtilizationMetrics": NotRequired[List["UtilizationMetricTypeDef"]],
+        "platformDifferences": NotRequired[List[PlatformDifferenceType]],
+        "performanceRisk": NotRequired[float],
+        "rank": NotRequired[int],
+        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
+        "migrationEffort": NotRequired[MigrationEffortType],
     },
-    total=False,
 )
 
 InstanceRecommendationTypeDef = TypedDict(
     "InstanceRecommendationTypeDef",
     {
-        "instanceArn": str,
-        "accountId": str,
-        "instanceName": str,
-        "currentInstanceType": str,
-        "finding": FindingType,
-        "findingReasonCodes": List[InstanceRecommendationFindingReasonCodeType],
-        "utilizationMetrics": List["UtilizationMetricTypeDef"],
-        "lookBackPeriodInDays": float,
-        "recommendationOptions": List["InstanceRecommendationOptionTypeDef"],
-        "recommendationSources": List["RecommendationSourceTypeDef"],
-        "lastRefreshTimestamp": datetime,
-        "currentPerformanceRisk": CurrentPerformanceRiskType,
-        "effectiveRecommendationPreferences": "EffectiveRecommendationPreferencesTypeDef",
-        "inferredWorkloadTypes": List[InferredWorkloadTypeType],
+        "instanceArn": NotRequired[str],
+        "accountId": NotRequired[str],
+        "instanceName": NotRequired[str],
+        "currentInstanceType": NotRequired[str],
+        "finding": NotRequired[FindingType],
+        "findingReasonCodes": NotRequired[List[InstanceRecommendationFindingReasonCodeType]],
+        "utilizationMetrics": NotRequired[List["UtilizationMetricTypeDef"]],
+        "lookBackPeriodInDays": NotRequired[float],
+        "recommendationOptions": NotRequired[List["InstanceRecommendationOptionTypeDef"]],
+        "recommendationSources": NotRequired[List["RecommendationSourceTypeDef"]],
+        "lastRefreshTimestamp": NotRequired[datetime],
+        "currentPerformanceRisk": NotRequired[CurrentPerformanceRiskType],
+        "effectiveRecommendationPreferences": NotRequired[
+            "EffectiveRecommendationPreferencesTypeDef"
+        ],
+        "inferredWorkloadTypes": NotRequired[List[InferredWorkloadTypeType]],
     },
-    total=False,
 )
 
 JobFilterTypeDef = TypedDict(
     "JobFilterTypeDef",
     {
-        "name": JobFilterNameType,
-        "values": Sequence[str],
+        "name": NotRequired[JobFilterNameType],
+        "values": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 LambdaFunctionMemoryProjectedMetricTypeDef = TypedDict(
     "LambdaFunctionMemoryProjectedMetricTypeDef",
     {
-        "name": Literal["Duration"],
-        "statistic": LambdaFunctionMemoryMetricStatisticType,
-        "value": float,
+        "name": NotRequired[Literal["Duration"]],
+        "statistic": NotRequired[LambdaFunctionMemoryMetricStatisticType],
+        "value": NotRequired[float],
     },
-    total=False,
 )
 
 LambdaFunctionMemoryRecommendationOptionTypeDef = TypedDict(
     "LambdaFunctionMemoryRecommendationOptionTypeDef",
     {
-        "rank": int,
-        "memorySize": int,
-        "projectedUtilizationMetrics": List["LambdaFunctionMemoryProjectedMetricTypeDef"],
-        "savingsOpportunity": "SavingsOpportunityTypeDef",
+        "rank": NotRequired[int],
+        "memorySize": NotRequired[int],
+        "projectedUtilizationMetrics": NotRequired[
+            List["LambdaFunctionMemoryProjectedMetricTypeDef"]
+        ],
+        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
     },
-    total=False,
 )
 
 LambdaFunctionRecommendationFilterTypeDef = TypedDict(
     "LambdaFunctionRecommendationFilterTypeDef",
     {
-        "name": LambdaFunctionRecommendationFilterNameType,
-        "values": Sequence[str],
+        "name": NotRequired[LambdaFunctionRecommendationFilterNameType],
+        "values": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 LambdaFunctionRecommendationTypeDef = TypedDict(
     "LambdaFunctionRecommendationTypeDef",
     {
-        "functionArn": str,
-        "functionVersion": str,
-        "accountId": str,
-        "currentMemorySize": int,
-        "numberOfInvocations": int,
-        "utilizationMetrics": List["LambdaFunctionUtilizationMetricTypeDef"],
-        "lookbackPeriodInDays": float,
-        "lastRefreshTimestamp": datetime,
-        "finding": LambdaFunctionRecommendationFindingType,
-        "findingReasonCodes": List[LambdaFunctionRecommendationFindingReasonCodeType],
-        "memorySizeRecommendationOptions": List["LambdaFunctionMemoryRecommendationOptionTypeDef"],
-        "currentPerformanceRisk": CurrentPerformanceRiskType,
+        "functionArn": NotRequired[str],
+        "functionVersion": NotRequired[str],
+        "accountId": NotRequired[str],
+        "currentMemorySize": NotRequired[int],
+        "numberOfInvocations": NotRequired[int],
+        "utilizationMetrics": NotRequired[List["LambdaFunctionUtilizationMetricTypeDef"]],
+        "lookbackPeriodInDays": NotRequired[float],
+        "lastRefreshTimestamp": NotRequired[datetime],
+        "finding": NotRequired[LambdaFunctionRecommendationFindingType],
+        "findingReasonCodes": NotRequired[List[LambdaFunctionRecommendationFindingReasonCodeType]],
+        "memorySizeRecommendationOptions": NotRequired[
+            List["LambdaFunctionMemoryRecommendationOptionTypeDef"]
+        ],
+        "currentPerformanceRisk": NotRequired[CurrentPerformanceRiskType],
     },
-    total=False,
 )
 
 LambdaFunctionUtilizationMetricTypeDef = TypedDict(
     "LambdaFunctionUtilizationMetricTypeDef",
     {
-        "name": LambdaFunctionMetricNameType,
-        "statistic": LambdaFunctionMetricStatisticType,
-        "value": float,
+        "name": NotRequired[LambdaFunctionMetricNameType],
+        "statistic": NotRequired[LambdaFunctionMetricStatisticType],
+        "value": NotRequired[float],
     },
-    total=False,
 )
 
 ProjectedMetricTypeDef = TypedDict(
     "ProjectedMetricTypeDef",
     {
-        "name": MetricNameType,
-        "timestamps": List[datetime],
-        "values": List[float],
+        "name": NotRequired[MetricNameType],
+        "timestamps": NotRequired[List[datetime]],
+        "values": NotRequired[List[float]],
     },
-    total=False,
 )
 
-_RequiredPutRecommendationPreferencesRequestRequestTypeDef = TypedDict(
-    "_RequiredPutRecommendationPreferencesRequestRequestTypeDef",
+PutRecommendationPreferencesRequestRequestTypeDef = TypedDict(
+    "PutRecommendationPreferencesRequestRequestTypeDef",
     {
         "resourceType": ResourceTypeType,
+        "scope": NotRequired["ScopeTypeDef"],
+        "enhancedInfrastructureMetrics": NotRequired[EnhancedInfrastructureMetricsType],
+        "inferredWorkloadTypes": NotRequired[InferredWorkloadTypesPreferenceType],
     },
 )
-_OptionalPutRecommendationPreferencesRequestRequestTypeDef = TypedDict(
-    "_OptionalPutRecommendationPreferencesRequestRequestTypeDef",
-    {
-        "scope": "ScopeTypeDef",
-        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
-        "inferredWorkloadTypes": InferredWorkloadTypesPreferenceType,
-    },
-    total=False,
-)
-
-
-class PutRecommendationPreferencesRequestRequestTypeDef(
-    _RequiredPutRecommendationPreferencesRequestRequestTypeDef,
-    _OptionalPutRecommendationPreferencesRequestRequestTypeDef,
-):
-    pass
-
 
 ReasonCodeSummaryTypeDef = TypedDict(
     "ReasonCodeSummaryTypeDef",
     {
-        "name": FindingReasonCodeType,
-        "value": float,
+        "name": NotRequired[FindingReasonCodeType],
+        "value": NotRequired[float],
     },
-    total=False,
 )
 
 RecommendationExportJobTypeDef = TypedDict(
     "RecommendationExportJobTypeDef",
     {
-        "jobId": str,
-        "destination": "ExportDestinationTypeDef",
-        "resourceType": ResourceTypeType,
-        "status": JobStatusType,
-        "creationTimestamp": datetime,
-        "lastUpdatedTimestamp": datetime,
-        "failureReason": str,
+        "jobId": NotRequired[str],
+        "destination": NotRequired["ExportDestinationTypeDef"],
+        "resourceType": NotRequired[ResourceTypeType],
+        "status": NotRequired[JobStatusType],
+        "creationTimestamp": NotRequired[datetime],
+        "lastUpdatedTimestamp": NotRequired[datetime],
+        "failureReason": NotRequired[str],
     },
-    total=False,
 )
 
 RecommendationPreferencesDetailTypeDef = TypedDict(
     "RecommendationPreferencesDetailTypeDef",
     {
-        "scope": "ScopeTypeDef",
-        "resourceType": ResourceTypeType,
-        "enhancedInfrastructureMetrics": EnhancedInfrastructureMetricsType,
-        "inferredWorkloadTypes": InferredWorkloadTypesPreferenceType,
+        "scope": NotRequired["ScopeTypeDef"],
+        "resourceType": NotRequired[ResourceTypeType],
+        "enhancedInfrastructureMetrics": NotRequired[EnhancedInfrastructureMetricsType],
+        "inferredWorkloadTypes": NotRequired[InferredWorkloadTypesPreferenceType],
     },
-    total=False,
 )
 
 RecommendationPreferencesTypeDef = TypedDict(
     "RecommendationPreferencesTypeDef",
     {
-        "cpuVendorArchitectures": Sequence[CpuVendorArchitectureType],
+        "cpuVendorArchitectures": NotRequired[Sequence[CpuVendorArchitectureType]],
     },
-    total=False,
 )
 
 RecommendationSourceTypeDef = TypedDict(
     "RecommendationSourceTypeDef",
     {
-        "recommendationSourceArn": str,
-        "recommendationSourceType": RecommendationSourceTypeType,
+        "recommendationSourceArn": NotRequired[str],
+        "recommendationSourceType": NotRequired[RecommendationSourceTypeType],
     },
-    total=False,
 )
 
 RecommendationSummaryTypeDef = TypedDict(
     "RecommendationSummaryTypeDef",
     {
-        "summaries": List["SummaryTypeDef"],
-        "recommendationResourceType": RecommendationSourceTypeType,
-        "accountId": str,
-        "savingsOpportunity": "SavingsOpportunityTypeDef",
-        "currentPerformanceRiskRatings": "CurrentPerformanceRiskRatingsTypeDef",
+        "summaries": NotRequired[List["SummaryTypeDef"]],
+        "recommendationResourceType": NotRequired[RecommendationSourceTypeType],
+        "accountId": NotRequired[str],
+        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
+        "currentPerformanceRiskRatings": NotRequired["CurrentPerformanceRiskRatingsTypeDef"],
     },
-    total=False,
 )
 
 RecommendedOptionProjectedMetricTypeDef = TypedDict(
     "RecommendedOptionProjectedMetricTypeDef",
     {
-        "recommendedInstanceType": str,
-        "rank": int,
-        "projectedMetrics": List["ProjectedMetricTypeDef"],
+        "recommendedInstanceType": NotRequired[str],
+        "rank": NotRequired[int],
+        "projectedMetrics": NotRequired[List["ProjectedMetricTypeDef"]],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -905,71 +767,52 @@ ResponseMetadataTypeDef = TypedDict(
 S3DestinationConfigTypeDef = TypedDict(
     "S3DestinationConfigTypeDef",
     {
-        "bucket": str,
-        "keyPrefix": str,
+        "bucket": NotRequired[str],
+        "keyPrefix": NotRequired[str],
     },
-    total=False,
 )
 
 S3DestinationTypeDef = TypedDict(
     "S3DestinationTypeDef",
     {
-        "bucket": str,
-        "key": str,
-        "metadataKey": str,
+        "bucket": NotRequired[str],
+        "key": NotRequired[str],
+        "metadataKey": NotRequired[str],
     },
-    total=False,
 )
 
 SavingsOpportunityTypeDef = TypedDict(
     "SavingsOpportunityTypeDef",
     {
-        "savingsOpportunityPercentage": float,
-        "estimatedMonthlySavings": "EstimatedMonthlySavingsTypeDef",
+        "savingsOpportunityPercentage": NotRequired[float],
+        "estimatedMonthlySavings": NotRequired["EstimatedMonthlySavingsTypeDef"],
     },
-    total=False,
 )
 
 ScopeTypeDef = TypedDict(
     "ScopeTypeDef",
     {
-        "name": ScopeNameType,
-        "value": str,
+        "name": NotRequired[ScopeNameType],
+        "value": NotRequired[str],
     },
-    total=False,
 )
 
 SummaryTypeDef = TypedDict(
     "SummaryTypeDef",
     {
-        "name": FindingType,
-        "value": float,
-        "reasonCodeSummaries": List["ReasonCodeSummaryTypeDef"],
+        "name": NotRequired[FindingType],
+        "value": NotRequired[float],
+        "reasonCodeSummaries": NotRequired[List["ReasonCodeSummaryTypeDef"]],
     },
-    total=False,
 )
 
-_RequiredUpdateEnrollmentStatusRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateEnrollmentStatusRequestRequestTypeDef",
+UpdateEnrollmentStatusRequestRequestTypeDef = TypedDict(
+    "UpdateEnrollmentStatusRequestRequestTypeDef",
     {
         "status": StatusType,
+        "includeMemberAccounts": NotRequired[bool],
     },
 )
-_OptionalUpdateEnrollmentStatusRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateEnrollmentStatusRequestRequestTypeDef",
-    {
-        "includeMemberAccounts": bool,
-    },
-    total=False,
-)
-
-
-class UpdateEnrollmentStatusRequestRequestTypeDef(
-    _RequiredUpdateEnrollmentStatusRequestRequestTypeDef,
-    _OptionalUpdateEnrollmentStatusRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateEnrollmentStatusResponseTypeDef = TypedDict(
     "UpdateEnrollmentStatusResponseTypeDef",
@@ -983,49 +826,45 @@ UpdateEnrollmentStatusResponseTypeDef = TypedDict(
 UtilizationMetricTypeDef = TypedDict(
     "UtilizationMetricTypeDef",
     {
-        "name": MetricNameType,
-        "statistic": MetricStatisticType,
-        "value": float,
+        "name": NotRequired[MetricNameType],
+        "statistic": NotRequired[MetricStatisticType],
+        "value": NotRequired[float],
     },
-    total=False,
 )
 
 VolumeConfigurationTypeDef = TypedDict(
     "VolumeConfigurationTypeDef",
     {
-        "volumeType": str,
-        "volumeSize": int,
-        "volumeBaselineIOPS": int,
-        "volumeBurstIOPS": int,
-        "volumeBaselineThroughput": int,
-        "volumeBurstThroughput": int,
+        "volumeType": NotRequired[str],
+        "volumeSize": NotRequired[int],
+        "volumeBaselineIOPS": NotRequired[int],
+        "volumeBurstIOPS": NotRequired[int],
+        "volumeBaselineThroughput": NotRequired[int],
+        "volumeBurstThroughput": NotRequired[int],
     },
-    total=False,
 )
 
 VolumeRecommendationOptionTypeDef = TypedDict(
     "VolumeRecommendationOptionTypeDef",
     {
-        "configuration": "VolumeConfigurationTypeDef",
-        "performanceRisk": float,
-        "rank": int,
-        "savingsOpportunity": "SavingsOpportunityTypeDef",
+        "configuration": NotRequired["VolumeConfigurationTypeDef"],
+        "performanceRisk": NotRequired[float],
+        "rank": NotRequired[int],
+        "savingsOpportunity": NotRequired["SavingsOpportunityTypeDef"],
     },
-    total=False,
 )
 
 VolumeRecommendationTypeDef = TypedDict(
     "VolumeRecommendationTypeDef",
     {
-        "volumeArn": str,
-        "accountId": str,
-        "currentConfiguration": "VolumeConfigurationTypeDef",
-        "finding": EBSFindingType,
-        "utilizationMetrics": List["EBSUtilizationMetricTypeDef"],
-        "lookBackPeriodInDays": float,
-        "volumeRecommendationOptions": List["VolumeRecommendationOptionTypeDef"],
-        "lastRefreshTimestamp": datetime,
-        "currentPerformanceRisk": CurrentPerformanceRiskType,
+        "volumeArn": NotRequired[str],
+        "accountId": NotRequired[str],
+        "currentConfiguration": NotRequired["VolumeConfigurationTypeDef"],
+        "finding": NotRequired[EBSFindingType],
+        "utilizationMetrics": NotRequired[List["EBSUtilizationMetricTypeDef"]],
+        "lookBackPeriodInDays": NotRequired[float],
+        "volumeRecommendationOptions": NotRequired[List["VolumeRecommendationOptionTypeDef"]],
+        "lastRefreshTimestamp": NotRequired[datetime],
+        "currentPerformanceRisk": NotRequired[CurrentPerformanceRiskType],
     },
-    total=False,
 )
